MediaFrameReference class

A wrapper class that represents a frame obtained from a MediaFrameSource. Use the properties of this class to access the specific frame type provided by the source, such as a VideoMediaFrame or BufferMediaFrame.

Implemented types

Constructors

MediaFrameReference.fromPtr(Pointer<COMObject> ptr)

Properties

audioMediaFrame AudioMediaFrame?
no setteroverride
bufferMediaFrame BufferMediaFrame?
no setteroverride
coordinateSystem → SpatialCoordinateSystem?
no setteroverride
duration Duration
no setteroverride
format MediaFrameFormat?
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
properties Map<Guid, Object?>?
no setteroverride
ptr Pointer<COMObject>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceKind MediaFrameSourceKind
no setteroverride
systemRelativeTime Duration?
no setteroverride
videoMediaFrame VideoMediaFrame?
no setteroverride

Methods

addRef() int
Increments the reference count for an interface pointer to a COM object.
inherited
close() → void
override
detach() → void
Detaches the object from the Finalizer.
inherited
getIids(Pointer<Uint32> iidCount, Pointer<Pointer<GUID>> iids) int
inherited
getRuntimeClassName(Pointer<IntPtr> className) int
inherited
getTrustLevel(Pointer<Int32> trustLevel) int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface(Pointer<GUID> riid, Pointer<Pointer<NativeType>> ppvObject) int
Queries a COM object for a pointer to one of its interface; identifying the interface by a reference to its interface identifier (IID).
inherited
release() int
Decrements the reference count for an interface on a COM object.
inherited
toInterface(String iid) Pointer<COMObject>
Cast an existing COM object to a specified interface.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited