MediaPropertySet class
Represents a set of media properties.
Constructors
- MediaPropertySet()
-
MediaPropertySet.fromPtr(Pointer<
COMObject> ptr)
Properties
Methods
-
addRef(
) → int -
Increments the reference count for an interface pointer to a COM object.
inherited
-
clear(
) → void - Removes all items from the map.
-
detach(
) → void -
Detaches the object from the
Finalizer.inherited -
first(
) → IIterator< IKeyValuePair< Guid, Object?> > - Returns an iterator for the items in the collection.
-
getIids(
Pointer< Uint32> iidCount, Pointer<Pointer< iids) → intGUID> > -
inherited
-
getRuntimeClassName(
Pointer< IntPtr> className) → int -
inherited
-
getTrustLevel(
Pointer< Int32> trustLevel) → int -
inherited
-
getView(
) → Map< Guid, Object?> - Returns an immutable view of the map.
-
hasKey(
Guid key) → bool - Determines whether the map contains the specified key.
-
insert(
Guid key, Object? value) → bool - Inserts or replaces an item in the map.
-
lookup(
Guid key) → Object? - Returns the item at the specified key in the map.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface(
Pointer< GUID> riid, Pointer<Pointer< ppvObject) → intNativeType> > -
Queries a COM object for a pointer to one of its interface; identifying
the interface by a reference to its interface identifier (IID).
inherited
-
release(
) → int -
Decrements the reference count for an interface on a COM object.
inherited
-
remove(
Guid key) → void - Removes an item from the map.
-
toInterface(
String iid) → Pointer< COMObject> -
Cast an existing COM object to a specified interface.
inherited
-
toMap(
) → Map< Guid, Object?> -
Creates an unmodifiable Map from the current
IMapinstance. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Guid key) → Object? -
The value for the given
key, ornullifkeyis not in the map. -
operator []=(
Guid key, Object? value) → void -
Associates the
keywith the givenvalue.